@@ -39,8 +39,8 @@ func (self *CommitCommands) SetAuthor(value string) error {
 }
 
 // Add a commit's coauthor using Github/Gitlab Co-authored-by metadata. Value is expected to be of the form 'Name <Email>'
-func (self *CommitCommands) AddCoAuthor(sha string, author string) error {
-	message, err := self.GetCommitMessage(sha)
+func (self *CommitCommands) AddCoAuthor(hash string, author string) error {
+	message, err := self.GetCommitMessage(hash)
 	if err != nil {
 		return err
 	}
@@ -74,8 +74,8 @@ func AddCoAuthorToDescription(description string, author string) string {
 }
 
 // ResetToCommit reset to commit
-func (self *CommitCommands) ResetToCommit(sha string, strength string, envVars []string) error {
-	cmdArgs := NewGitCmd("reset").Arg("--"+strength, sha).ToArgv()
+func (self *CommitCommands) ResetToCommit(hash string, strength string, envVars []string) error {
+	cmdArgs := NewGitCmd("reset").Arg("--"+strength, hash).ToArgv()
 
 	return self.cmd.New(cmdArgs).
 		// prevents git from prompting us for input which would freeze the program
@@ -155,26 +155,28 @@ func (self *CommitCommands) signoffFlag() string {
 	}
 }
 
-func (self *CommitCommands) GetCommitMessage(commitSha string) (string, error) {
+func (self *CommitCommands) GetCommitMessage(commitHash string) (string, error) {
 	cmdArgs := NewGitCmd("log").
-		Arg("--format=%B", "--max-count=1", commitSha).
+		Arg("--format=%B", "--max-count=1", commitHash).
+		Config("log.showsignature=false").
 		ToArgv()
 
 	message, err := self.cmd.New(cmdArgs).DontLog().RunWithOutput()
 	return strings.ReplaceAll(strings.TrimSpace(message), "\r\n", "\n"), err
 }
 
-func (self *CommitCommands) GetCommitSubject(commitSha string) (string, error) {
+func (self *CommitCommands) GetCommitSubject(commitHash string) (string, error) {
 	cmdArgs := NewGitCmd("log").
-		Arg("--format=%s", "--max-count=1", commitSha).
+		Arg("--format=%s", "--max-count=1", commitHash).
+		Config("log.showsignature=false").
 		ToArgv()
 
 	subject, err := self.cmd.New(cmdArgs).DontLog().RunWithOutput()
 	return strings.TrimSpace(subject), err
 }
 
-func (self *CommitCommands) GetCommitDiff(commitSha string) (string, error) {
-	cmdArgs := NewGitCmd("show").Arg("--no-color", commitSha).ToArgv()
+func (self *CommitCommands) GetCommitDiff(commitHash string) (string, error) {
+	cmdArgs := NewGitCmd("show").Arg("--no-color", commitHash).ToArgv()
 
 	diff, err := self.cmd.New(cmdArgs).DontLog().RunWithOutput()
 	return diff, err
@@ -185,9 +187,9 @@ type Author struct {
 	Email string
 }
 
-func (self *CommitCommands) GetCommitAuthor(commitSha string) (Author, error) {
+func (self *CommitCommands) GetCommitAuthor(commitHash string) (Author, error) {
 	cmdArgs := NewGitCmd("show").
-		Arg("--no-patch", "--pretty=format:'%an%x00%ae'", commitSha).
+		Arg("--no-patch", "--pretty=format:'%an%x00%ae'", commitHash).
 		ToArgv()
 
 	output, err := self.cmd.New(cmdArgs).DontLog().RunWithOutput()
@@ -204,14 +206,14 @@ func (self *CommitCommands) GetCommitAuthor(commitSha string) (Author, error) {
 	return author, err
 }
 
-func (self *CommitCommands) GetCommitMessageFirstLine(sha string) (string, error) {
-	return self.GetCommitMessagesFirstLine([]string{sha})
+func (self *CommitCommands) GetCommitMessageFirstLine(hash string) (string, error) {
+	return self.GetCommitMessagesFirstLine([]string{hash})
 }
 
-func (self *CommitCommands) GetCommitMessagesFirstLine(shas []string) (string, error) {
+func (self *CommitCommands) GetCommitMessagesFirstLine(hashes []string) (string, error) {
 	cmdArgs := NewGitCmd("show").
 		Arg("--no-patch", "--pretty=format:%s").
-		Arg(shas...).
+		Arg(hashes...).
 		ToArgv()
 
 	return self.cmd.New(cmdArgs).DontLog().RunWithOutput()
@@ -222,19 +224,19 @@ func (self *CommitCommands) GetCommitMessagesFirstLine(shas []string) (string, e
 //	cd50c79ae Preserve the commit message correctly even if the description has blank lines
 //	3ebba5f32 Add test demonstrating a bug with preserving the commit message
 //	9a423c388 Remove unused function
-func (self *CommitCommands) GetShasAndCommitMessagesFirstLine(shas []string) (string, error) {
+func (self *CommitCommands) GetHashesAndCommitMessagesFirstLine(hashes []string) (string, error) {
 	cmdArgs := NewGitCmd("show").
 		Arg("--no-patch", "--pretty=format:%h %s").
-		Arg(shas...).
+		Arg(hashes...).
 		ToArgv()
 
 	return self.cmd.New(cmdArgs).DontLog().RunWithOutput()
 }
 
-func (self *CommitCommands) GetCommitsOneline(shas []string) (string, error) {
+func (self *CommitCommands) GetCommitsOneline(hashes []string) (string, error) {
 	cmdArgs := NewGitCmd("show").
 		Arg("--no-patch", "--oneline").
-		Arg(shas...).
+		Arg(hashes...).
 		ToArgv()
 
 	return self.cmd.New(cmdArgs).DontLog().RunWithOutput()
@@ -253,7 +255,7 @@ func (self *CommitCommands) AmendHeadCmdObj() oscommands.ICmdObj {
 	return self.cmd.New(cmdArgs)
 }
 
-func (self *CommitCommands) ShowCmdObj(sha string, filterPath string) oscommands.ICmdObj {
+func (self *CommitCommands) ShowCmdObj(hash string, filterPath string) oscommands.ICmdObj {
 	contextSize := self.AppState.DiffContextSize
 
 	extDiffCmd := self.UserConfig.Git.Paging.ExternalDiffCommand
@@ -267,7 +269,7 @@ func (self *CommitCommands) ShowCmdObj(sha string, filterPath string) oscommands
 		Arg("--stat").
 		Arg("--decorate").
 		Arg("-p").
-		Arg(sha).
+		Arg(hash).
 		ArgIf(self.AppState.IgnoreWhitespaceInDiffView, "--ignore-all-space").
 		ArgIf(filterPath != "", "--", filterPath).
 		Dir(self.repoPaths.worktreePath).
@@ -276,23 +278,23 @@ func (self *CommitCommands) ShowCmdObj(sha string, filterPath string) oscommands
 	return self.cmd.New(cmdArgs).DontLog()
 }
 
-// Revert reverts the selected commit by sha
-func (self *CommitCommands) Revert(sha string) error {
-	cmdArgs := NewGitCmd("revert").Arg(sha).ToArgv()
+// Revert reverts the selected commit by hash
+func (self *CommitCommands) Revert(hash string) error {
+	cmdArgs := NewGitCmd("revert").Arg(hash).ToArgv()
 
 	return self.cmd.New(cmdArgs).Run()
 }
 
-func (self *CommitCommands) RevertMerge(sha string, parentNumber int) error {
-	cmdArgs := NewGitCmd("revert").Arg(sha, "-m", fmt.Sprintf("%d", parentNumber)).
+func (self *CommitCommands) RevertMerge(hash string, parentNumber int) error {
+	cmdArgs := NewGitCmd("revert").Arg(hash, "-m", fmt.Sprintf("%d", parentNumber)).
 		ToArgv()
 
 	return self.cmd.New(cmdArgs).Run()
 }
 
 // CreateFixupCommit creates a commit that fixes up a previous commit
-func (self *CommitCommands) CreateFixupCommit(sha string) error {
-	cmdArgs := NewGitCmd("commit").Arg("--fixup=" + sha).ToArgv()
+func (self *CommitCommands) CreateFixupCommit(hash string) error {
+	cmdArgs := NewGitCmd("commit").Arg("--fixup=" + hash).ToArgv()
 
 	return self.cmd.New(cmdArgs).Run()
 }
