@@ -5,26 +5,26 @@ import (
 	"strings"
 	"testing"
 
-	"github.com/fsmiamoto/git-todo-parser/todo"
 	"github.com/go-errors/errors"
 	"github.com/jesseduffield/lazygit/pkg/commands/models"
 	"github.com/jesseduffield/lazygit/pkg/commands/oscommands"
 	"github.com/jesseduffield/lazygit/pkg/commands/types/enums"
 	"github.com/jesseduffield/lazygit/pkg/config"
 	"github.com/jesseduffield/lazygit/pkg/utils"
+	"github.com/stefanhaller/git-todo-parser/todo"
 	"github.com/stretchr/testify/assert"
 )
 
-var commitsOutput = strings.Replace(`0eea75e8c631fba6b58135697835d58ba4c18dbc|1640826609|Jesse Duffield|jessedduffield@gmail.com|HEAD -> better-tests|b21997d6b4cbdf84b149|better typing for rebase mode
-b21997d6b4cbdf84b149d8e6a2c4d06a8e9ec164|1640824515|Jesse Duffield|jessedduffield@gmail.com|origin/better-tests|e94e8fc5b6fab4cb755f|fix logging
-e94e8fc5b6fab4cb755f29f1bdb3ee5e001df35c|1640823749|Jesse Duffield|jessedduffield@gmail.com|tag: 123, tag: 456|d8084cd558925eb7c9c3|refactor
-d8084cd558925eb7c9c38afeed5725c21653ab90|1640821426|Jesse Duffield|jessedduffield@gmail.com||65f910ebd85283b5cce9|WIP
-65f910ebd85283b5cce9bf67d03d3f1a9ea3813a|1640821275|Jesse Duffield|jessedduffield@gmail.com||26c07b1ab33860a1a759|WIP
-26c07b1ab33860a1a7591a0638f9925ccf497ffa|1640750752|Jesse Duffield|jessedduffield@gmail.com||3d4470a6c072208722e5|WIP
-3d4470a6c072208722e5ae9a54bcb9634959a1c5|1640748818|Jesse Duffield|jessedduffield@gmail.com||053a66a7be3da43aacdc|WIP
-053a66a7be3da43aacdc7aa78e1fe757b82c4dd2|1640739815|Jesse Duffield|jessedduffield@gmail.com||985fe482e806b172aea4|refactoring the config struct`, "|", "\x00", -1)
+var commitsOutput = strings.Replace(`0eea75e8c631fba6b58135697835d58ba4c18dbc|1640826609|Jesse Duffield|jessedduffield@gmail.com|HEAD -> better-tests|b21997d6b4cbdf84b149|>|better typing for rebase mode
+b21997d6b4cbdf84b149d8e6a2c4d06a8e9ec164|1640824515|Jesse Duffield|jessedduffield@gmail.com|origin/better-tests|e94e8fc5b6fab4cb755f|>|fix logging
+e94e8fc5b6fab4cb755f29f1bdb3ee5e001df35c|1640823749|Jesse Duffield|jessedduffield@gmail.com|tag: 123, tag: 456|d8084cd558925eb7c9c3|>|refactor
+d8084cd558925eb7c9c38afeed5725c21653ab90|1640821426|Jesse Duffield|jessedduffield@gmail.com||65f910ebd85283b5cce9|>|WIP
+65f910ebd85283b5cce9bf67d03d3f1a9ea3813a|1640821275|Jesse Duffield|jessedduffield@gmail.com||26c07b1ab33860a1a759|>|WIP
+26c07b1ab33860a1a7591a0638f9925ccf497ffa|1640750752|Jesse Duffield|jessedduffield@gmail.com||3d4470a6c072208722e5|>|WIP
+3d4470a6c072208722e5ae9a54bcb9634959a1c5|1640748818|Jesse Duffield|jessedduffield@gmail.com||053a66a7be3da43aacdc|>|WIP
+053a66a7be3da43aacdc7aa78e1fe757b82c4dd2|1640739815|Jesse Duffield|jessedduffield@gmail.com||985fe482e806b172aea4|>|refactoring the config struct`, "|", "\x00", -1)
 
-var singleCommitOutput = strings.Replace(`0eea75e8c631fba6b58135697835d58ba4c18dbc|1640826609|Jesse Duffield|jessedduffield@gmail.com|HEAD -> better-tests|b21997d6b4cbdf84b149|better typing for rebase mode`, "|", "\x00", -1)
+var singleCommitOutput = strings.Replace(`0eea75e8c631fba6b58135697835d58ba4c18dbc|1640826609|Jesse Duffield|jessedduffield@gmail.com|HEAD -> better-tests|b21997d6b4cbdf84b149|>|better typing for rebase mode`, "|", "\x00", -1)
 
 func TestGetCommits(t *testing.T) {
 	type scenario struct {
@@ -46,7 +46,7 @@ func TestGetCommits(t *testing.T) {
 			opts:       GetCommitsOptions{RefName: "HEAD", RefForPushedStatus: "mybranch", IncludeRebaseCommits: false},
 			runner: oscommands.NewFakeRunner(t).
 				ExpectGitArgs([]string{"merge-base", "mybranch", "mybranch@{u}"}, "b21997d6b4cbdf84b149d8e6a2c4d06a8e9ec164", nil).
-				ExpectGitArgs([]string{"log", "HEAD", "--topo-order", "--oneline", "--pretty=format:%H%x00%at%x00%aN%x00%ae%x00%D%x00%p%x00%s%x00%m", "--abbrev=40", "--no-show-signature", "--"}, "", nil),
+				ExpectGitArgs([]string{"log", "HEAD", "--topo-order", "--oneline", "--pretty=format:%H%x00%at%x00%aN%x00%ae%x00%D%x00%p%x00%m%x00%s", "--abbrev=40", "--no-show-signature", "--"}, "", nil),
 
 			expectedCommits: []*models.Commit{},
 			expectedError:   nil,
@@ -58,7 +58,7 @@ func TestGetCommits(t *testing.T) {
 			opts:       GetCommitsOptions{RefName: "refs/heads/mybranch", RefForPushedStatus: "refs/heads/mybranch", IncludeRebaseCommits: false},
 			runner: oscommands.NewFakeRunner(t).
 				ExpectGitArgs([]string{"merge-base", "refs/heads/mybranch", "mybranch@{u}"}, "b21997d6b4cbdf84b149d8e6a2c4d06a8e9ec164", nil).
-				ExpectGitArgs([]string{"log", "refs/heads/mybranch", "--topo-order", "--oneline", "--pretty=format:%H%x00%at%x00%aN%x00%ae%x00%D%x00%p%x00%s%x00%m", "--abbrev=40", "--no-show-signature", "--"}, "", nil),
+				ExpectGitArgs([]string{"log", "refs/heads/mybranch", "--topo-order", "--oneline", "--pretty=format:%H%x00%at%x00%aN%x00%ae%x00%D%x00%p%x00%m%x00%s", "--abbrev=40", "--no-show-signature", "--"}, "", nil),
 
 			expectedCommits: []*models.Commit{},
 			expectedError:   nil,
@@ -73,7 +73,7 @@ func TestGetCommits(t *testing.T) {
 				// here it's seeing which commits are yet to be pushed
 				ExpectGitArgs([]string{"merge-base", "mybranch", "mybranch@{u}"}, "b21997d6b4cbdf84b149d8e6a2c4d06a8e9ec164", nil).
 				// here it's actually getting all the commits in a formatted form, one per line
-				ExpectGitArgs([]string{"log", "HEAD", "--topo-order", "--oneline", "--pretty=format:%H%x00%at%x00%aN%x00%ae%x00%D%x00%p%x00%s%x00%m", "--abbrev=40", "--no-show-signature", "--"}, commitsOutput, nil).
+				ExpectGitArgs([]string{"log", "HEAD", "--topo-order", "--oneline", "--pretty=format:%H%x00%at%x00%aN%x00%ae%x00%D%x00%p%x00%m%x00%s", "--abbrev=40", "--no-show-signature", "--"}, commitsOutput, nil).
 				// here it's testing which of the configured main branches have an upstream
 				ExpectGitArgs([]string{"rev-parse", "--symbolic-full-name", "master@{u}"}, "refs/remotes/origin/master", nil).       // this one does
 				ExpectGitArgs([]string{"rev-parse", "--symbolic-full-name", "main@{u}"}, "", errors.New("error")).                   // this one doesn't, so it checks origin instead
@@ -86,7 +86,7 @@ func TestGetCommits(t *testing.T) {
 
 			expectedCommits: []*models.Commit{
 				{
-					Sha:           "0eea75e8c631fba6b58135697835d58ba4c18dbc",
+					Hash:          "0eea75e8c631fba6b58135697835d58ba4c18dbc",
 					Name:          "better typing for rebase mode",
 					Status:        models.StatusUnpushed,
 					Action:        models.ActionNone,
@@ -100,7 +100,7 @@ func TestGetCommits(t *testing.T) {
 					},
 				},
 				{
-					Sha:           "b21997d6b4cbdf84b149d8e6a2c4d06a8e9ec164",
+					Hash:          "b21997d6b4cbdf84b149d8e6a2c4d06a8e9ec164",
 					Name:          "fix logging",
 					Status:        models.StatusPushed,
 					Action:        models.ActionNone,
@@ -114,7 +114,7 @@ func TestGetCommits(t *testing.T) {
 					},
 				},
 				{
-					Sha:           "e94e8fc5b6fab4cb755f29f1bdb3ee5e001df35c",
+					Hash:          "e94e8fc5b6fab4cb755f29f1bdb3ee5e001df35c",
 					Name:          "refactor",
 					Status:        models.StatusPushed,
 					Action:        models.ActionNone,
@@ -128,7 +128,7 @@ func TestGetCommits(t *testing.T) {
 					},
 				},
 				{
-					Sha:           "d8084cd558925eb7c9c38afeed5725c21653ab90",
+					Hash:          "d8084cd558925eb7c9c38afeed5725c21653ab90",
 					Name:          "WIP",
 					Status:        models.StatusPushed,
 					Action:        models.ActionNone,
@@ -142,7 +142,7 @@ func TestGetCommits(t *testing.T) {
 					},
 				},
 				{
-					Sha:           "65f910ebd85283b5cce9bf67d03d3f1a9ea3813a",
+					Hash:          "65f910ebd85283b5cce9bf67d03d3f1a9ea3813a",
 					Name:          "WIP",
 					Status:        models.StatusPushed,
 					Action:        models.ActionNone,
@@ -156,7 +156,7 @@ func TestGetCommits(t *testing.T) {
 					},
 				},
 				{
-					Sha:           "26c07b1ab33860a1a7591a0638f9925ccf497ffa",
+					Hash:          "26c07b1ab33860a1a7591a0638f9925ccf497ffa",
 					Name:          "WIP",
 					Status:        models.StatusMerged,
 					Action:        models.ActionNone,
@@ -170,7 +170,7 @@ func TestGetCommits(t *testing.T) {
 					},
 				},
 				{
-					Sha:           "3d4470a6c072208722e5ae9a54bcb9634959a1c5",
+					Hash:          "3d4470a6c072208722e5ae9a54bcb9634959a1c5",
 					Name:          "WIP",
 					Status:        models.StatusMerged,
 					Action:        models.ActionNone,
@@ -184,7 +184,7 @@ func TestGetCommits(t *testing.T) {
 					},
 				},
 				{
-					Sha:           "053a66a7be3da43aacdc7aa78e1fe757b82c4dd2",
+					Hash:          "053a66a7be3da43aacdc7aa78e1fe757b82c4dd2",
 					Name:          "refactoring the config struct",
 					Status:        models.StatusMerged,
 					Action:        models.ActionNone,
@@ -210,7 +210,7 @@ func TestGetCommits(t *testing.T) {
 				// here it's seeing which commits are yet to be pushed
 				ExpectGitArgs([]string{"merge-base", "mybranch", "mybranch@{u}"}, "b21997d6b4cbdf84b149d8e6a2c4d06a8e9ec164", nil).
 				// here it's actually getting all the commits in a formatted form, one per line
-				ExpectGitArgs([]string{"log", "HEAD", "--topo-order", "--oneline", "--pretty=format:%H%x00%at%x00%aN%x00%ae%x00%D%x00%p%x00%s%x00%m", "--abbrev=40", "--no-show-signature", "--"}, singleCommitOutput, nil).
+				ExpectGitArgs([]string{"log", "HEAD", "--topo-order", "--oneline", "--pretty=format:%H%x00%at%x00%aN%x00%ae%x00%D%x00%p%x00%m%x00%s", "--abbrev=40", "--no-show-signature", "--"}, singleCommitOutput, nil).
 				// here it's testing which of the configured main branches exist; neither does
 				ExpectGitArgs([]string{"rev-parse", "--symbolic-full-name", "master@{u}"}, "", errors.New("error")).
 				ExpectGitArgs([]string{"rev-parse", "--verify", "--quiet", "refs/remotes/origin/master"}, "", errors.New("error")).
@@ -221,7 +221,7 @@ func TestGetCommits(t *testing.T) {
 
 			expectedCommits: []*models.Commit{
 				{
-					Sha:           "0eea75e8c631fba6b58135697835d58ba4c18dbc",
+					Hash:          "0eea75e8c631fba6b58135697835d58ba4c18dbc",
 					Name:          "better typing for rebase mode",
 					Status:        models.StatusUnpushed,
 					Action:        models.ActionNone,
@@ -247,7 +247,7 @@ func TestGetCommits(t *testing.T) {
 				// here it's seeing which commits are yet to be pushed
 				ExpectGitArgs([]string{"merge-base", "mybranch", "mybranch@{u}"}, "b21997d6b4cbdf84b149d8e6a2c4d06a8e9ec164", nil).
 				// here it's actually getting all the commits in a formatted form, one per line
-				ExpectGitArgs([]string{"log", "HEAD", "--topo-order", "--oneline", "--pretty=format:%H%x00%at%x00%aN%x00%ae%x00%D%x00%p%x00%s%x00%m", "--abbrev=40", "--no-show-signature", "--"}, singleCommitOutput, nil).
+				ExpectGitArgs([]string{"log", "HEAD", "--topo-order", "--oneline", "--pretty=format:%H%x00%at%x00%aN%x00%ae%x00%D%x00%p%x00%m%x00%s", "--abbrev=40", "--no-show-signature", "--"}, singleCommitOutput, nil).
 				// here it's testing which of the configured main branches exist
 				ExpectGitArgs([]string{"rev-parse", "--symbolic-full-name", "master@{u}"}, "refs/remotes/origin/master", nil).
 				ExpectGitArgs([]string{"rev-parse", "--symbolic-full-name", "main@{u}"}, "", errors.New("error")).
@@ -260,7 +260,7 @@ func TestGetCommits(t *testing.T) {
 
 			expectedCommits: []*models.Commit{
 				{
-					Sha:           "0eea75e8c631fba6b58135697835d58ba4c18dbc",
+					Hash:          "0eea75e8c631fba6b58135697835d58ba4c18dbc",
 					Name:          "better typing for rebase mode",
 					Status:        models.StatusUnpushed,
 					Action:        models.ActionNone,
@@ -283,7 +283,7 @@ func TestGetCommits(t *testing.T) {
 			opts:       GetCommitsOptions{RefName: "HEAD", RefForPushedStatus: "mybranch", IncludeRebaseCommits: false},
 			runner: oscommands.NewFakeRunner(t).
 				ExpectGitArgs([]string{"merge-base", "mybranch", "mybranch@{u}"}, "b21997d6b4cbdf84b149d8e6a2c4d06a8e9ec164", nil).
-				ExpectGitArgs([]string{"log", "HEAD", "--oneline", "--pretty=format:%H%x00%at%x00%aN%x00%ae%x00%D%x00%p%x00%s%x00%m", "--abbrev=40", "--no-show-signature", "--"}, "", nil),
+				ExpectGitArgs([]string{"log", "HEAD", "--oneline", "--pretty=format:%H%x00%at%x00%aN%x00%ae%x00%D%x00%p%x00%m%x00%s", "--abbrev=40", "--no-show-signature", "--"}, "", nil),
 
 			expectedCommits: []*models.Commit{},
 			expectedError:   nil,
@@ -295,7 +295,7 @@ func TestGetCommits(t *testing.T) {
 			opts:       GetCommitsOptions{RefName: "HEAD", RefForPushedStatus: "mybranch", FilterPath: "src"},
 			runner: oscommands.NewFakeRunner(t).
 				ExpectGitArgs([]string{"merge-base", "mybranch", "mybranch@{u}"}, "b21997d6b4cbdf84b149d8e6a2c4d06a8e9ec164", nil).
-				ExpectGitArgs([]string{"log", "HEAD", "--oneline", "--pretty=format:%H%x00%at%x00%aN%x00%ae%x00%D%x00%p%x00%s%x00%m", "--abbrev=40", "--follow", "--no-show-signature", "--", "src"}, "", nil),
+				ExpectGitArgs([]string{"log", "HEAD", "--oneline", "--pretty=format:%H%x00%at%x00%aN%x00%ae%x00%D%x00%p%x00%m%x00%s", "--abbrev=40", "--follow", "--no-show-signature", "--", "src"}, "", nil),
 
 			expectedCommits: []*models.Commit{},
 			expectedError:   nil,
@@ -303,7 +303,6 @@ func TestGetCommits(t *testing.T) {
 	}
 
 	for _, scenario := range scenarios {
-		scenario := scenario
 		t.Run(scenario.testName, func(t *testing.T) {
 			common := utils.NewDummyCommon()
 			common.AppState = &config.AppState{}
@@ -339,14 +338,14 @@ func TestCommitLoader_getConflictedCommitImpl(t *testing.T) {
 		todos           []todo.Todo
 		doneTodos       []todo.Todo
 		amendFileExists bool
-		expectedSha     string
+		expectedHash    string
 	}{
 		{
 			testName:        "no done todos",
 			todos:           []todo.Todo{},
 			doneTodos:       []todo.Todo{},
 			amendFileExists: false,
-			expectedSha:     "",
+			expectedHash:    "",
 		},
 		{
 			testName: "common case (conflict)",
@@ -362,7 +361,7 @@ func TestCommitLoader_getConflictedCommitImpl(t *testing.T) {
 				},
 			},
 			amendFileExists: false,
-			expectedSha:     "fa1afe1",
+			expectedHash:    "fa1afe1",
 		},
 		{
 			testName: "last command was 'break'",
@@ -371,7 +370,7 @@ func TestCommitLoader_getConflictedCommitImpl(t *testing.T) {
 				{Command: todo.Break},
 			},
 			amendFileExists: false,
-			expectedSha:     "",
+			expectedHash:    "",
 		},
 		{
 			testName: "last command was 'exec'",
@@ -383,7 +382,7 @@ func TestCommitLoader_getConflictedCommitImpl(t *testing.T) {
 				},
 			},
 			amendFileExists: false,
-			expectedSha:     "",
+			expectedHash:    "",
 		},
 		{
 			testName: "last command was 'reword'",
@@ -392,7 +391,7 @@ func TestCommitLoader_getConflictedCommitImpl(t *testing.T) {
 				{Command: todo.Reword},
 			},
 			amendFileExists: false,
-			expectedSha:     "",
+			expectedHash:    "",
 		},
 		{
 			testName: "'pick' was rescheduled",
@@ -409,7 +408,7 @@ func TestCommitLoader_getConflictedCommitImpl(t *testing.T) {
 				},
 			},
 			amendFileExists: false,
-			expectedSha:     "",
+			expectedHash:    "",
 		},
 		{
 			testName: "'pick' was rescheduled, buggy git version",
@@ -434,7 +433,7 @@ func TestCommitLoader_getConflictedCommitImpl(t *testing.T) {
 				},
 			},
 			amendFileExists: false,
-			expectedSha:     "",
+			expectedHash:    "",
 		},
 		{
 			testName: "conflicting 'pick' after 'exec'",
@@ -459,7 +458,7 @@ func TestCommitLoader_getConflictedCommitImpl(t *testing.T) {
 				},
 			},
 			amendFileExists: false,
-			expectedSha:     "fa1afe1",
+			expectedHash:    "fa1afe1",
 		},
 		{
 			testName: "'edit' with amend file",
@@ -471,7 +470,7 @@ func TestCommitLoader_getConflictedCommitImpl(t *testing.T) {
 				},
 			},
 			amendFileExists: true,
-			expectedSha:     "",
+			expectedHash:    "",
 		},
 		{
 			testName: "'edit' without amend file",
@@ -483,7 +482,7 @@ func TestCommitLoader_getConflictedCommitImpl(t *testing.T) {
 				},
 			},
 			amendFileExists: false,
-			expectedSha:     "fa1afe1",
+			expectedHash:    "fa1afe1",
 		},
 	}
 	for _, scenario := range scenarios {
@@ -503,8 +502,8 @@ func TestCommitLoader_getConflictedCommitImpl(t *testing.T) {
 				},
 			}
 
-			sha := builder.getConflictedCommitImpl(scenario.todos, scenario.doneTodos, scenario.amendFileExists)
-			assert.Equal(t, scenario.expectedSha, sha)
+			hash := builder.getConflictedCommitImpl(scenario.todos, scenario.doneTodos, scenario.amendFileExists)
+			assert.Equal(t, scenario.expectedHash, hash)
 		})
 	}
 }
@@ -521,29 +520,29 @@ func TestCommitLoader_setCommitMergedStatuses(t *testing.T) {
 		{
 			testName: "basic",
 			commits: []*models.Commit{
-				{Sha: "12345", Name: "1", Action: models.ActionNone, Status: models.StatusUnpushed},
-				{Sha: "67890", Name: "2", Action: models.ActionNone, Status: models.StatusPushed},
-				{Sha: "abcde", Name: "3", Action: models.ActionNone, Status: models.StatusPushed},
+				{Hash: "12345", Name: "1", Action: models.ActionNone, Status: models.StatusUnpushed},
+				{Hash: "67890", Name: "2", Action: models.ActionNone, Status: models.StatusPushed},
+				{Hash: "abcde", Name: "3", Action: models.ActionNone, Status: models.StatusPushed},
 			},
 			ancestor: "67890",
 			expectedCommits: []*models.Commit{
-				{Sha: "12345", Name: "1", Action: models.ActionNone, Status: models.StatusUnpushed},
-				{Sha: "67890", Name: "2", Action: models.ActionNone, Status: models.StatusMerged},
-				{Sha: "abcde", Name: "3", Action: models.ActionNone, Status: models.StatusMerged},
+				{Hash: "12345", Name: "1", Action: models.ActionNone, Status: models.StatusUnpushed},
+				{Hash: "67890", Name: "2", Action: models.ActionNone, Status: models.StatusMerged},
+				{Hash: "abcde", Name: "3", Action: models.ActionNone, Status: models.StatusMerged},
 			},
 		},
 		{
 			testName: "with update-ref",
 			commits: []*models.Commit{
-				{Sha: "12345", Name: "1", Action: models.ActionNone, Status: models.StatusUnpushed},
-				{Sha: "", Name: "", Action: todo.UpdateRef, Status: models.StatusNone},
-				{Sha: "abcde", Name: "3", Action: models.ActionNone, Status: models.StatusPushed},
+				{Hash: "12345", Name: "1", Action: models.ActionNone, Status: models.StatusUnpushed},
+				{Hash: "", Name: "", Action: todo.UpdateRef, Status: models.StatusNone},
+				{Hash: "abcde", Name: "3", Action: models.ActionNone, Status: models.StatusPushed},
 			},
 			ancestor: "deadbeef",
 			expectedCommits: []*models.Commit{
-				{Sha: "12345", Name: "1", Action: models.ActionNone, Status: models.StatusUnpushed},
-				{Sha: "", Name: "", Action: todo.UpdateRef, Status: models.StatusNone},
-				{Sha: "abcde", Name: "3", Action: models.ActionNone, Status: models.StatusPushed},
+				{Hash: "12345", Name: "1", Action: models.ActionNone, Status: models.StatusUnpushed},
+				{Hash: "", Name: "", Action: todo.UpdateRef, Status: models.StatusNone},
+				{Hash: "abcde", Name: "3", Action: models.ActionNone, Status: models.StatusPushed},
 			},
 		},
 	}
