@@ -5,13 +5,13 @@ import (
 	"path/filepath"
 	"strings"
 
-	"github.com/fsmiamoto/git-todo-parser/todo"
 	"github.com/go-errors/errors"
 	"github.com/jesseduffield/lazygit/pkg/app/daemon"
 	"github.com/jesseduffield/lazygit/pkg/commands/models"
 	"github.com/jesseduffield/lazygit/pkg/commands/oscommands"
 	"github.com/jesseduffield/lazygit/pkg/utils"
 	"github.com/samber/lo"
+	"github.com/stefanhaller/git-todo-parser/todo"
 )
 
 type RebaseCommands struct {
@@ -56,14 +56,14 @@ func (self *RebaseCommands) RewordCommit(commits []*models.Commit, index int, su
 
 func (self *RebaseCommands) RewordCommitInEditor(commits []*models.Commit, index int) (oscommands.ICmdObj, error) {
 	changes := []daemon.ChangeTodoAction{{
-		Sha:       commits[index].Sha,
+		Hash:      commits[index].Hash,
 		NewAction: todo.Reword,
 	}}
 	self.os.LogCommand(logTodoChanges(changes), false)
 
 	return self.PrepareInteractiveRebaseCommand(PrepareInteractiveRebaseCommandOpts{
-		baseShaOrRoot: getBaseShaOrRoot(commits, index+1),
-		instruction:   daemon.NewChangeTodoActionsInstruction(changes),
+		baseHashOrRoot: getBaseHashOrRoot(commits, index+1),
+		instruction:    daemon.NewChangeTodoActionsInstruction(changes),
 	}), nil
 }
 
@@ -81,7 +81,7 @@ func (self *RebaseCommands) SetCommitAuthor(commits []*models.Commit, index int,
 
 func (self *RebaseCommands) AddCommitCoAuthor(commits []*models.Commit, index int, value string) error {
 	return self.GenericAmend(commits, index, func() error {
-		return self.commit.AddCoAuthor(commits[index].Sha, value)
+		return self.commit.AddCoAuthor(commits[index].Hash, value)
 	})
 }
 
@@ -106,29 +106,29 @@ func (self *RebaseCommands) GenericAmend(commits []*models.Commit, index int, f
 }
 
 func (self *RebaseCommands) MoveCommitsDown(commits []*models.Commit, startIdx int, endIdx int) error {
-	baseShaOrRoot := getBaseShaOrRoot(commits, endIdx+2)
+	baseHashOrRoot := getBaseHashOrRoot(commits, endIdx+2)
 
-	shas := lo.Map(commits[startIdx:endIdx+1], func(commit *models.Commit, _ int) string {
-		return commit.Sha
+	hashes := lo.Map(commits[startIdx:endIdx+1], func(commit *models.Commit, _ int) string {
+		return commit.Hash
 	})
 
 	return self.PrepareInteractiveRebaseCommand(PrepareInteractiveRebaseCommandOpts{
-		baseShaOrRoot:  baseShaOrRoot,
-		instruction:    daemon.NewMoveTodosDownInstruction(shas),
+		baseHashOrRoot: baseHashOrRoot,
+		instruction:    daemon.NewMoveTodosDownInstruction(hashes),
 		overrideEditor: true,
 	}).Run()
 }
 
 func (self *RebaseCommands) MoveCommitsUp(commits []*models.Commit, startIdx int, endIdx int) error {
-	baseShaOrRoot := getBaseShaOrRoot(commits, endIdx+1)
+	baseHashOrRoot := getBaseHashOrRoot(commits, endIdx+1)
 
-	shas := lo.Map(commits[startIdx:endIdx+1], func(commit *models.Commit, _ int) string {
-		return commit.Sha
+	hashes := lo.Map(commits[startIdx:endIdx+1], func(commit *models.Commit, _ int) string {
+		return commit.Hash
 	})
 
 	return self.PrepareInteractiveRebaseCommand(PrepareInteractiveRebaseCommandOpts{
-		baseShaOrRoot:  baseShaOrRoot,
-		instruction:    daemon.NewMoveTodosUpInstruction(shas),
+		baseHashOrRoot: baseHashOrRoot,
+		instruction:    daemon.NewMoveTodosUpInstruction(hashes),
 		overrideEditor: true,
 	}).Run()
 }
@@ -139,11 +139,11 @@ func (self *RebaseCommands) InteractiveRebase(commits []*models.Commit, startIdx
 		baseIndex++
 	}
 
-	baseShaOrRoot := getBaseShaOrRoot(commits, baseIndex)
+	baseHashOrRoot := getBaseHashOrRoot(commits, baseIndex)
 
 	changes := lo.Map(commits[startIdx:endIdx+1], func(commit *models.Commit, _ int) daemon.ChangeTodoAction {
 		return daemon.ChangeTodoAction{
-			Sha:       commit.Sha,
+			Hash:      commit.Hash,
 			NewAction: action,
 		}
 	})
@@ -151,7 +151,7 @@ func (self *RebaseCommands) InteractiveRebase(commits []*models.Commit, startIdx
 	self.os.LogCommand(logTodoChanges(changes), false)
 
 	return self.PrepareInteractiveRebaseCommand(PrepareInteractiveRebaseCommandOpts{
-		baseShaOrRoot:  baseShaOrRoot,
+		baseHashOrRoot: baseHashOrRoot,
 		overrideEditor: true,
 		instruction:    daemon.NewChangeTodoActionsInstruction(changes),
 	}).Run()
@@ -166,8 +166,8 @@ func (self *RebaseCommands) EditRebase(branchRef string) error {
 	)
 	self.os.LogCommand(msg, false)
 	return self.PrepareInteractiveRebaseCommand(PrepareInteractiveRebaseCommandOpts{
-		baseShaOrRoot: branchRef,
-		instruction:   daemon.NewInsertBreakInstruction(),
+		baseHashOrRoot: branchRef,
+		instruction:    daemon.NewInsertBreakInstruction(),
 	}).Run()
 }
 
@@ -181,21 +181,21 @@ func (self *RebaseCommands) EditRebaseFromBaseCommit(targetBranchName string, ba
 	)
 	self.os.LogCommand(msg, false)
 	return self.PrepareInteractiveRebaseCommand(PrepareInteractiveRebaseCommandOpts{
-		baseShaOrRoot: baseCommit,
-		onto:          targetBranchName,
-		instruction:   daemon.NewInsertBreakInstruction(),
+		baseHashOrRoot: baseCommit,
+		onto:           targetBranchName,
+		instruction:    daemon.NewInsertBreakInstruction(),
 	}).Run()
 }
 
 func logTodoChanges(changes []daemon.ChangeTodoAction) string {
 	changeTodoStr := strings.Join(lo.Map(changes, func(c daemon.ChangeTodoAction, _ int) string {
-		return fmt.Sprintf("%s:%s", c.Sha, c.NewAction)
+		return fmt.Sprintf("%s:%s", c.Hash, c.NewAction)
 	}), "\n")
 	return fmt.Sprintf("Changing TODO actions:\n%s", changeTodoStr)
 }
 
 type PrepareInteractiveRebaseCommandOpts struct {
-	baseShaOrRoot              string
+	baseHashOrRoot             string
 	onto                       string
 	instruction                daemon.Instruction
 	overrideEditor             bool
@@ -204,7 +204,7 @@ type PrepareInteractiveRebaseCommandOpts struct {
 
 // PrepareInteractiveRebaseCommand returns the cmd for an interactive rebase
 // we tell git to run lazygit to edit the todo list, and we pass the client
-// lazygit a todo string to write to the todo file
+// lazygit instructions what to do with the todo file
 func (self *RebaseCommands) PrepareInteractiveRebaseCommand(opts PrepareInteractiveRebaseCommandOpts) oscommands.ICmdObj {
 	ex := oscommands.GetLazygitPath()
 
@@ -216,7 +216,7 @@ func (self *RebaseCommands) PrepareInteractiveRebaseCommand(opts PrepareInteract
 		Arg("--no-autosquash").
 		ArgIf(self.version.IsAtLeast(2, 22, 0), "--rebase-merges").
 		ArgIf(opts.onto != "", "--onto", opts.onto).
-		Arg(opts.baseShaOrRoot).
+		Arg(opts.baseHashOrRoot).
 		ToArgv()
 
 	debug := "FALSE"
@@ -233,7 +233,7 @@ func (self *RebaseCommands) PrepareInteractiveRebaseCommand(opts PrepareInteract
 	if opts.instruction != nil {
 		cmdObj.AddEnvVars(daemon.ToEnvVars(opts.instruction)...)
 	} else {
-		gitSequenceEditor = "true"
+		cmdObj.AddEnvVars(daemon.ToEnvVars(daemon.NewRemoveUpdateRefsForCopiedBranchInstruction())...)
 	}
 
 	cmdObj.AddEnvVars(
@@ -250,25 +250,55 @@ func (self *RebaseCommands) PrepareInteractiveRebaseCommand(opts PrepareInteract
 	return cmdObj
 }
 
+// GitRebaseEditTodo runs "git rebase --edit-todo", saving the given todosFileContent to the file
+func (self *RebaseCommands) GitRebaseEditTodo(todosFileContent []byte) error {
+	ex := oscommands.GetLazygitPath()
+
+	cmdArgs := NewGitCmd("rebase").
+		Arg("--edit-todo").
+		ToArgv()
+
+	debug := "FALSE"
+	if self.Debug {
+		debug = "TRUE"
+	}
+
+	self.Log.WithField("command", cmdArgs).Debug("RunCommand")
+
+	cmdObj := self.cmd.New(cmdArgs)
+
+	cmdObj.AddEnvVars(daemon.ToEnvVars(daemon.NewWriteRebaseTodoInstruction(todosFileContent))...)
+
+	cmdObj.AddEnvVars(
+		"DEBUG="+debug,
+		"LANG=en_US.UTF-8",   // Force using EN as language
+		"LC_ALL=en_US.UTF-8", // Force using EN as language
+		"GIT_EDITOR="+ex,
+		"GIT_SEQUENCE_EDITOR="+ex,
+	)
+
+	return cmdObj.Run()
+}
+
 // AmendTo amends the given commit with whatever files are staged
 func (self *RebaseCommands) AmendTo(commits []*models.Commit, commitIndex int) error {
 	commit := commits[commitIndex]
 
-	if err := self.commit.CreateFixupCommit(commit.Sha); err != nil {
+	if err := self.commit.CreateFixupCommit(commit.Hash); err != nil {
 		return err
 	}
 
-	// Get the sha of the commit we just created
+	// Get the hash of the commit we just created
 	cmdArgs := NewGitCmd("rev-parse").Arg("--verify", "HEAD").ToArgv()
-	fixupSha, err := self.cmd.New(cmdArgs).RunWithOutput()
+	fixupHash, err := self.cmd.New(cmdArgs).RunWithOutput()
 	if err != nil {
 		return err
 	}
 
 	return self.PrepareInteractiveRebaseCommand(PrepareInteractiveRebaseCommandOpts{
-		baseShaOrRoot:  getBaseShaOrRoot(commits, commitIndex+1),
+		baseHashOrRoot: getBaseHashOrRoot(commits, commitIndex+1),
 		overrideEditor: true,
-		instruction:    daemon.NewMoveFixupCommitDownInstruction(commit.Sha, fixupSha),
+		instruction:    daemon.NewMoveFixupCommitDownInstruction(commit.Hash, fixupHash),
 	}).Run()
 }
 
@@ -276,7 +306,7 @@ func todoFromCommit(commit *models.Commit) utils.Todo {
 	if commit.Action == todo.UpdateRef {
 		return utils.Todo{Ref: commit.Name, Action: commit.Action}
 	} else {
-		return utils.Todo{Sha: commit.Sha, Action: commit.Action}
+		return utils.Todo{Hash: commit.Hash, Action: commit.Action}
 	}
 }
 
@@ -284,7 +314,7 @@ func todoFromCommit(commit *models.Commit) utils.Todo {
 func (self *RebaseCommands) EditRebaseTodo(commits []*models.Commit, action todo.TodoCommand) error {
 	commitsWithAction := lo.Map(commits, func(commit *models.Commit, _ int) utils.TodoChange {
 		return utils.TodoChange{
-			Sha:       commit.Sha,
+			Hash:      commit.Hash,
 			OldAction: commit.Action,
 			NewAction: action,
 		}
@@ -302,11 +332,16 @@ func (self *RebaseCommands) DeleteUpdateRefTodos(commits []*models.Commit) error
 		return todoFromCommit(commit)
 	})
 
-	return utils.DeleteTodos(
+	todosFileContent, err := utils.DeleteTodos(
 		filepath.Join(self.repoPaths.WorktreeGitDirPath(), "rebase-merge/git-rebase-todo"),
 		todosToDelete,
 		self.config.GetCoreCommentChar(),
 	)
+	if err != nil {
+		return err
+	}
+
+	return self.GitRebaseEditTodo(todosFileContent)
 }
 
 func (self *RebaseCommands) MoveTodosDown(commits []*models.Commit) error {
@@ -329,13 +364,13 @@ func (self *RebaseCommands) MoveTodosUp(commits []*models.Commit) error {
 
 // SquashAllAboveFixupCommits squashes all fixup! commits above the given one
 func (self *RebaseCommands) SquashAllAboveFixupCommits(commit *models.Commit) error {
-	shaOrRoot := commit.Sha + "^"
+	hashOrRoot := commit.Hash + "^"
 	if commit.IsFirstCommit() {
-		shaOrRoot = "--root"
+		hashOrRoot = "--root"
 	}
 
 	cmdArgs := NewGitCmd("rebase").
-		Arg("--interactive", "--rebase-merges", "--autostash", "--autosquash", shaOrRoot).
+		Arg("--interactive", "--rebase-merges", "--autostash", "--autosquash", hashOrRoot).
 		ToArgv()
 
 	return self.runSkipEditorCommand(self.cmd.New(cmdArgs))
@@ -358,13 +393,13 @@ func (self *RebaseCommands) BeginInteractiveRebaseForCommit(
 	}
 
 	changes := []daemon.ChangeTodoAction{{
-		Sha:       commits[commitIndex].Sha,
+		Hash:      commits[commitIndex].Hash,
 		NewAction: todo.Edit,
 	}}
 	self.os.LogCommand(logTodoChanges(changes), false)
 
 	return self.PrepareInteractiveRebaseCommand(PrepareInteractiveRebaseCommandOpts{
-		baseShaOrRoot:              getBaseShaOrRoot(commits, commitIndex+1),
+		baseHashOrRoot:             getBaseHashOrRoot(commits, commitIndex+1),
 		overrideEditor:             true,
 		keepCommitsThatBecomeEmpty: keepCommitsThatBecomeEmpty,
 		instruction:                daemon.NewChangeTodoActionsInstruction(changes),
@@ -373,13 +408,13 @@ func (self *RebaseCommands) BeginInteractiveRebaseForCommit(
 
 // RebaseBranch interactive rebases onto a branch
 func (self *RebaseCommands) RebaseBranch(branchName string) error {
-	return self.PrepareInteractiveRebaseCommand(PrepareInteractiveRebaseCommandOpts{baseShaOrRoot: branchName}).Run()
+	return self.PrepareInteractiveRebaseCommand(PrepareInteractiveRebaseCommandOpts{baseHashOrRoot: branchName}).Run()
 }
 
 func (self *RebaseCommands) RebaseBranchFromBaseCommit(targetBranchName string, baseCommit string) error {
 	return self.PrepareInteractiveRebaseCommand(PrepareInteractiveRebaseCommandOpts{
-		baseShaOrRoot: baseCommit,
-		onto:          targetBranchName,
+		baseHashOrRoot: baseCommit,
+		onto:           targetBranchName,
 	}).Run()
 }
 
@@ -468,10 +503,10 @@ func (self *RebaseCommands) DiscardOldFileChanges(commits []*models.Commit, comm
 	return self.ContinueRebase()
 }
 
-// CherryPickCommits begins an interactive rebase with the given shas being cherry picked onto HEAD
+// CherryPickCommits begins an interactive rebase with the given hashes being cherry picked onto HEAD
 func (self *RebaseCommands) CherryPickCommits(commits []*models.Commit) error {
 	commitLines := lo.Map(commits, func(commit *models.Commit, _ int) string {
-		return fmt.Sprintf("%s %s", utils.ShortSha(commit.Sha), commit.Name)
+		return fmt.Sprintf("%s %s", utils.ShortHash(commit.Hash), commit.Name)
 	})
 	msg := utils.ResolvePlaceholderString(
 		self.Tr.Log.CherryPickCommits,
@@ -482,8 +517,8 @@ func (self *RebaseCommands) CherryPickCommits(commits []*models.Commit) error {
 	self.os.LogCommand(msg, false)
 
 	return self.PrepareInteractiveRebaseCommand(PrepareInteractiveRebaseCommandOpts{
-		baseShaOrRoot: "HEAD",
-		instruction:   daemon.NewCherryPickCommitsInstruction(commits),
+		baseHashOrRoot: "HEAD",
+		instruction:    daemon.NewCherryPickCommitsInstruction(commits),
 	}).Run()
 }
 
@@ -503,13 +538,13 @@ func (self *RebaseCommands) CherryPickCommitsDuringRebase(commits []*models.Comm
 
 // we can't start an interactive rebase from the first commit without passing the
 // '--root' arg
-func getBaseShaOrRoot(commits []*models.Commit, index int) string {
+func getBaseHashOrRoot(commits []*models.Commit, index int) string {
 	// We assume that the commits slice contains the initial commit of the repo.
 	// Technically this assumption could prove false, but it's unlikely you'll
 	// be starting a rebase from 300 commits ago (which is the original commit limit
 	// at time of writing)
 	if index < len(commits) {
-		return commits[index].Sha
+		return commits[index].Hash
 	} else {
 		return "--root"
 	}
