@@ -3,6 +3,9 @@ package models
 // Tag : A git tag
 type Tag struct {
 	Name string
+	// this is either the first line of the message of an annotated tag, or the
+	// first line of a commit message for a lightweight tag
+	Message string
 }
 
 func (t *Tag) FullRefName() string {
@@ -21,6 +24,10 @@ func (t *Tag) ID() string {
 	return t.RefName()
 }
 
+func (t *Tag) URN() string {
+	return "tag-" + t.ID()
+}
+
 func (t *Tag) Description() string {
-	return "tag " + t.Name
+	return t.Message
 }
