@@ -123,6 +123,8 @@ type GuiConfig struct {
 	NerdFontsVersion string `yaml:"nerdFontsVersion" jsonschema:"enum=2,enum=3,enum="`
 	// If true (default), file icons are shown in the file views. Only relevant if NerdFontsVersion is not empty.
 	ShowFileIcons bool `yaml:"showFileIcons"`
+	// Length of commit hash in commits view. 0 shows '*' if NF icons aren't on.
+	CommitHashLength int `yaml:"commitHashLength" jsonschema:"minimum=0"`
 	// If true, show commit hashes alongside branch names in the branches view.
 	ShowBranchCommitHash bool `yaml:"showBranchCommitHash"`
 	// Height of the command log view
@@ -145,6 +147,11 @@ type GuiConfig struct {
 	// How things are filtered when typing '/'.
 	// One of 'substring' (default) | 'fuzzy'
 	FilterMode string `yaml:"filterMode" jsonschema:"enum=substring,enum=fuzzy"`
+	// Config relating to the spinner.
+	Spinner SpinnerConfig `yaml:"spinner"`
+	// Status panel view.
+	// One of 'dashboard' (default) | 'allBranchesLog'
+	StatusPanelView string `yaml:"statusPanelView" jsonschema:"enum=dashboard,enum=allBranchesLog"`
 }
 
 func (c *GuiConfig) UseFuzzySearch() bool {
@@ -182,6 +189,13 @@ type CommitLengthConfig struct {
 	Show bool `yaml:"show"`
 }
 
+type SpinnerConfig struct {
+	// The frames of the spinner animation.
+	Frames []string `yaml:"frames"`
+	// The "speed" of the spinner in milliseconds.
+	Rate int `yaml:"rate" jsonschema:"minimum=1"`
+}
+
 type GitConfig struct {
 	// See https://github.com/jesseduffield/lazygit/blob/master/docs/Custom_Pagers.md
 	Paging PagingConfig `yaml:"paging"`
@@ -208,6 +222,8 @@ type GitConfig struct {
 	// If true, do not allow force pushes
 	DisableForcePushing bool `yaml:"disableForcePushing"`
 	// See https://github.com/jesseduffield/lazygit/blob/master/docs/Config.md#predefined-commit-message-prefix
+	CommitPrefix *CommitPrefixConfig `yaml:"commitPrefix"`
+	// See https://github.com/jesseduffield/lazygit/blob/master/docs/Config.md#predefined-commit-message-prefix
 	CommitPrefixes map[string]CommitPrefixConfig `yaml:"commitPrefixes"`
 	// If true, parse emoji strings in commit messages e.g. render :rocket: as 🚀
 	// (This should really be under 'gui', not 'git')
@@ -663,6 +679,7 @@ func GetDefaultConfig() *UserConfig {
 			ShowIcons:                 false,
 			NerdFontsVersion:          "",
 			ShowFileIcons:             true,
+			CommitHashLength:          8,
 			ShowBranchCommitHash:      false,
 			CommandLogSize:            8,
 			SplitDiff:                 "auto",
@@ -671,6 +688,11 @@ func GetDefaultConfig() *UserConfig {
 			AnimateExplosion:          true,
 			PortraitMode:              "auto",
 			FilterMode:                "substring",
+			Spinner: SpinnerConfig{
+				Frames: []string{"|", "/", "-", "\\"},
+				Rate:   50,
+			},
+			StatusPanelView: "dashboard",
 		},
 		Git: GitConfig{
 			Paging: PagingConfig{
