@@ -209,7 +209,7 @@ func (self *BranchesController) viewUpstreamOptions(selectedBranch *models.Branc
 		LabelColumns: []string{self.c.Tr.UnsetUpstream},
 		OnPress: func() error {
 			if err := self.c.Git().Branch.UnsetUpstream(selectedBranch.Name); err != nil {
-				return self.c.Error(err)
+				return err
 			}
 			if err := self.c.Refresh(types.RefreshOptions{
 				Mode: types.SYNC,
@@ -218,7 +218,7 @@ func (self *BranchesController) viewUpstreamOptions(selectedBranch *models.Branc
 					types.COMMITS,
 				},
 			}); err != nil {
-				return self.c.Error(err)
+				return err
 			}
 			return nil
 		},
@@ -231,11 +231,11 @@ func (self *BranchesController) viewUpstreamOptions(selectedBranch *models.Branc
 			return self.c.Helpers().Upstream.PromptForUpstreamWithoutInitialContent(selectedBranch, func(upstream string) error {
 				upstreamRemote, upstreamBranch, err := self.c.Helpers().Upstream.ParseUpstream(upstream)
 				if err != nil {
-					return self.c.Error(err)
+					return err
 				}
 
 				if err := self.c.Git().Branch.SetUpstream(upstreamRemote, upstreamBranch, selectedBranch.Name); err != nil {
-					return self.c.Error(err)
+					return err
 				}
 				if err := self.c.Refresh(types.RefreshOptions{
 					Mode: types.SYNC,
@@ -244,7 +244,7 @@ func (self *BranchesController) viewUpstreamOptions(selectedBranch *models.Branc
 						types.COMMITS,
 					},
 				}); err != nil {
-					return self.c.Error(err)
+					return err
 				}
 				return nil
 			})
@@ -279,7 +279,7 @@ func (self *BranchesController) viewUpstreamOptions(selectedBranch *models.Branc
 		OnPress: func() error {
 			err := self.c.Helpers().Refs.CreateGitResetMenu(upstream)
 			if err != nil {
-				return self.c.Error(err)
+				return err
 			}
 			return nil
 		},
@@ -292,7 +292,7 @@ func (self *BranchesController) viewUpstreamOptions(selectedBranch *models.Branc
 		OpensMenu:    true,
 		OnPress: func() error {
 			if err := self.c.Helpers().MergeAndRebase.RebaseOntoRef(selectedBranch.ShortUpstreamRefName()); err != nil {
-				return self.c.Error(err)
+				return err
 			}
 			return nil
 		},
@@ -334,7 +334,7 @@ func (self *BranchesController) context() *context.BranchesContext {
 
 func (self *BranchesController) press(selectedBranch *models.Branch) error {
 	if selectedBranch == self.c.Helpers().Refs.GetCheckedOutRef() {
-		return self.c.ErrorMsg(self.c.Tr.AlreadyCheckedOutBranch)
+		return errors.New(self.c.Tr.AlreadyCheckedOutBranch)
 	}
 
 	worktreeForRef, ok := self.worktreeForBranch(selectedBranch)
@@ -378,7 +378,7 @@ func (self *BranchesController) promptToCheckoutWorktree(worktree *models.Worktr
 
 func (self *BranchesController) handleCreatePullRequest(selectedBranch *models.Branch) error {
 	if !selectedBranch.IsTrackingRemote() {
-		return self.c.ErrorMsg(self.c.Tr.PullRequestNoUpstream)
+		return errors.New(self.c.Tr.PullRequestNoUpstream)
 	}
 	return self.createPullRequest(selectedBranch.UpstreamBranch, "")
 }
@@ -395,16 +395,16 @@ func (self *BranchesController) copyPullRequestURL() error {
 	branchExistsOnRemote := self.c.Git().Remote.CheckRemoteBranchExists(branch.Name)
 
 	if !branchExistsOnRemote {
-		return self.c.Error(errors.New(self.c.Tr.NoBranchOnRemote))
+		return errors.New(self.c.Tr.NoBranchOnRemote)
 	}
 
 	url, err := self.c.Helpers().Host.GetPullRequestURL(branch.Name, "")
 	if err != nil {
-		return self.c.Error(err)
+		return err
 	}
 	self.c.LogAction(self.c.Tr.Actions.CopyPullRequestURL)
 	if err := self.c.OS().CopyToClipboard(url); err != nil {
-		return self.c.Error(err)
+		return err
 	}
 
 	self.c.Toast(self.c.Tr.PullRequestURLCopiedToClipboard)
@@ -423,7 +423,7 @@ func (self *BranchesController) forceCheckout() error {
 		HandleConfirm: func() error {
 			self.c.LogAction(self.c.Tr.Actions.ForceCheckoutBranch)
 			if err := self.c.Git().Branch.Checkout(branch.Name, git_commands.CheckoutOptions{Force: true}); err != nil {
-				_ = self.c.Error(err)
+				return err
 			}
 			return self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC})
 		},
@@ -463,7 +463,7 @@ func (self *BranchesController) createNewBranchWithName(newBranchName string) er
 	}
 
 	if err := self.c.Git().Branch.New(newBranchName, branch.FullRefName()); err != nil {
-		return self.c.Error(err)
+		return err
 	}
 
 	self.context().SetSelection(0)
@@ -524,7 +524,7 @@ func (self *BranchesController) localDelete(branch *models.Branch) error {
 			return self.forceDelete(branch)
 		}
 		if err != nil {
-			return self.c.Error(err)
+			return err
 		}
 		return self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC, Scope: []types.RefreshableView{types.BRANCHES}})
 	})
@@ -548,7 +548,7 @@ func (self *BranchesController) forceDelete(branch *models.Branch) error {
 		Prompt: message,
 		HandleConfirm: func() error {
 			if err := self.c.Git().Branch.LocalDelete(branch.Name, true); err != nil {
-				return self.c.ErrorMsg(err.Error())
+				return err
 			}
 			return self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC, Scope: []types.RefreshableView{types.BRANCHES}})
 		},
@@ -615,13 +615,13 @@ func (self *BranchesController) notRebasingOntoSelf(branch *models.Branch) *type
 
 func (self *BranchesController) fastForward(branch *models.Branch) error {
 	if !branch.IsTrackingRemote() {
-		return self.c.ErrorMsg(self.c.Tr.FwdNoUpstream)
+		return errors.New(self.c.Tr.FwdNoUpstream)
 	}
 	if !branch.RemoteBranchStoredLocally() {
-		return self.c.ErrorMsg(self.c.Tr.FwdNoLocalUpstream)
+		return errors.New(self.c.Tr.FwdNoLocalUpstream)
 	}
-	if branch.HasCommitsToPush() {
-		return self.c.ErrorMsg(self.c.Tr.FwdCommitsToPush)
+	if branch.IsAheadForPull() {
+		return errors.New(self.c.Tr.FwdCommitsToPush)
 	}
 
 	action := self.c.Tr.Actions.FastForwardBranch
@@ -688,7 +688,7 @@ func (self *BranchesController) rename(branch *models.Branch) error {
 			HandleConfirm: func(newBranchName string) error {
 				self.c.LogAction(self.c.Tr.Actions.RenameBranch)
 				if err := self.c.Git().Branch.Rename(branch.Name, helpers.SanitizedBranchName(newBranchName)); err != nil {
-					return self.c.Error(err)
+					return err
 				}
 
 				// need to find where the branch is now so that we can re-select it. That means we need to refetch the branches synchronously and then find our branch
@@ -766,7 +766,7 @@ func (self *BranchesController) createPullRequestMenu(selectedBranch *models.Bra
 				LabelColumns: fromToLabelColumns(checkedOutBranch.Name, selectedBranch.Name),
 				OnPress: func() error {
 					if !checkedOutBranch.IsTrackingRemote() || !selectedBranch.IsTrackingRemote() {
-						return self.c.ErrorMsg(self.c.Tr.PullRequestNoUpstream)
+						return errors.New(self.c.Tr.PullRequestNoUpstream)
 					}
 					return self.createPullRequest(checkedOutBranch.UpstreamBranch, selectedBranch.UpstreamBranch)
 				},
@@ -783,13 +783,13 @@ func (self *BranchesController) createPullRequestMenu(selectedBranch *models.Bra
 func (self *BranchesController) createPullRequest(from string, to string) error {
 	url, err := self.c.Helpers().Host.GetPullRequestURL(from, to)
 	if err != nil {
-		return self.c.Error(err)
+		return err
 	}
 
 	self.c.LogAction(self.c.Tr.Actions.OpenPullRequest)
 
 	if err := self.c.OS().OpenLink(url); err != nil {
-		return self.c.Error(err)
+		return err
 	}
 
 	return nil
