@@ -1,22 +1,23 @@
 package controllers
 
 import (
+	"github.com/jesseduffield/lazygit/pkg/gui/context"
 	"github.com/jesseduffield/lazygit/pkg/gui/types"
 )
 
 type CommitDescriptionController struct {
 	baseController
-	*controllerCommon
+	c *ControllerCommon
 }
 
 var _ types.IController = &CommitMessageController{}
 
 func NewCommitDescriptionController(
-	common *controllerCommon,
+	c *ControllerCommon,
 ) *CommitDescriptionController {
 	return &CommitDescriptionController{
-		baseController:   baseController{},
-		controllerCommon: common,
+		baseController: baseController{},
+		c:              c,
 	}
 }
 
@@ -34,6 +35,10 @@ func (self *CommitDescriptionController) GetKeybindings(opts types.KeybindingsOp
 			Key:     opts.GetKey(opts.Config.Universal.ConfirmInEditor),
 			Handler: self.confirm,
 		},
+		{
+			Key:     opts.GetKey(opts.Config.CommitMessage.CommitMenu),
+			Handler: self.openCommitMenu,
+		},
 	}
 
 	return bindings
@@ -43,18 +48,23 @@ func (self *CommitDescriptionController) Context() types.Context {
 	return self.context()
 }
 
-func (self *CommitDescriptionController) context() types.Context {
-	return self.contexts.CommitMessage
+func (self *CommitDescriptionController) context() *context.CommitMessageContext {
+	return self.c.Contexts().CommitMessage
 }
 
 func (self *CommitDescriptionController) switchToCommitMessage() error {
-	return self.c.PushContext(self.contexts.CommitMessage)
+	return self.c.PushContext(self.c.Contexts().CommitMessage)
 }
 
 func (self *CommitDescriptionController) close() error {
-	return self.helpers.Commits.CloseCommitMessagePanel()
+	return self.c.Helpers().Commits.CloseCommitMessagePanel()
 }
 
 func (self *CommitDescriptionController) confirm() error {
-	return self.helpers.Commits.HandleCommitConfirm()
+	return self.c.Helpers().Commits.HandleCommitConfirm()
+}
+
+func (self *CommitDescriptionController) openCommitMenu() error {
+	authorSuggestion := self.c.Helpers().Suggestions.GetAuthorsSuggestionsFunc()
+	return self.c.Helpers().Commits.OpenCommitMenu(authorSuggestion)
 }
