@@ -1,6 +1,8 @@
 package helpers
 
 import (
+	"errors"
+	"fmt"
 	"regexp"
 	"strings"
 	"sync"
@@ -36,33 +38,33 @@ func (self *FixupHelper) HandleFindBaseCommitForFixupPress() error {
 		return err
 	}
 	if diff == "" {
-		return self.c.ErrorMsg(self.c.Tr.NoChangedFiles)
+		return errors.New(self.c.Tr.NoChangedFiles)
 	}
 
 	deletedLineInfos, hasHunksWithOnlyAddedLines := self.parseDiff(diff)
 	if len(deletedLineInfos) == 0 {
-		return self.c.ErrorMsg(self.c.Tr.NoDeletedLinesInDiff)
+		return errors.New(self.c.Tr.NoDeletedLinesInDiff)
 	}
 
-	shas := self.blameDeletedLines(deletedLineInfos)
+	hashes := self.blameDeletedLines(deletedLineInfos)
 
-	if len(shas) == 0 {
+	if len(hashes) == 0 {
 		// This should never happen
-		return self.c.ErrorMsg(self.c.Tr.NoBaseCommitsFound)
+		return errors.New(self.c.Tr.NoBaseCommitsFound)
 	}
-	if len(shas) > 1 {
-		subjects, err := self.c.Git().Commit.GetShasAndCommitMessagesFirstLine(shas)
+	if len(hashes) > 1 {
+		subjects, err := self.c.Git().Commit.GetHashesAndCommitMessagesFirstLine(hashes)
 		if err != nil {
 			return err
 		}
 		message := lo.Ternary(hasStagedChanges,
 			self.c.Tr.MultipleBaseCommitsFoundStaged,
 			self.c.Tr.MultipleBaseCommitsFoundUnstaged)
-		return self.c.ErrorMsg(message + "\n\n" + subjects)
+		return fmt.Errorf("%s\n\n%s", message, subjects)
 	}
 
 	commit, index, ok := lo.FindIndexOf(self.c.Model().Commits, func(commit *models.Commit) bool {
-		return commit.Sha == shas[0]
+		return commit.Hash == hashes[0]
 	})
 	if !ok {
 		commits := self.c.Model().Commits
@@ -70,13 +72,13 @@ func (self *FixupHelper) HandleFindBaseCommitForFixupPress() error {
 			// If the commit is not found, it's most likely because it's already
 			// merged, and more than 300 commits away. Check if the last known
 			// commit is already merged; if so, show the "already merged" error.
-			return self.c.ErrorMsg(self.c.Tr.BaseCommitIsAlreadyOnMainBranch)
+			return errors.New(self.c.Tr.BaseCommitIsAlreadyOnMainBranch)
 		}
 		// If we get here, the current branch must have more then 300 commits. Unlikely...
-		return self.c.ErrorMsg(self.c.Tr.BaseCommitIsNotInCurrentView)
+		return errors.New(self.c.Tr.BaseCommitIsNotInCurrentView)
 	}
 	if commit.Status == models.StatusMerged {
-		return self.c.ErrorMsg(self.c.Tr.BaseCommitIsAlreadyOnMainBranch)
+		return errors.New(self.c.Tr.BaseCommitIsAlreadyOnMainBranch)
 	}
 
 	doIt := func() error {
@@ -164,7 +166,7 @@ func (self *FixupHelper) parseDiff(diff string) ([]*deletedLineInfo, bool) {
 // returns the list of commit hashes that introduced the lines which have now been deleted
 func (self *FixupHelper) blameDeletedLines(deletedLineInfos []*deletedLineInfo) []string {
 	var wg sync.WaitGroup
-	shaChan := make(chan string)
+	hashChan := make(chan string)
 
 	for _, info := range deletedLineInfos {
 		wg.Add(1)
@@ -178,19 +180,19 @@ func (self *FixupHelper) blameDeletedLines(deletedLineInfos []*deletedLineInfo)
 			}
 			blameLines := strings.Split(strings.TrimSuffix(blameOutput, "\n"), "\n")
 			for _, line := range blameLines {
-				shaChan <- strings.Split(line, " ")[0]
+				hashChan <- strings.Split(line, " ")[0]
 			}
 		}(info)
 	}
 
 	go func() {
 		wg.Wait()
-		close(shaChan)
+		close(hashChan)
 	}()
 
 	result := set.New[string]()
-	for sha := range shaChan {
-		result.Add(sha)
+	for hash := range hashChan {
+		result.Add(hash)
 	}
 
 	return result.ToSlice()
