@@ -69,10 +69,10 @@ func (self *RefsHelper) CheckoutRef(ref string, options types.CheckoutRefOptions
 					Prompt: self.c.Tr.AutoStashPrompt,
 					HandleConfirm: func() error {
 						if err := self.c.Git().Stash.Push(self.c.Tr.StashPrefix + ref); err != nil {
-							return self.c.Error(err)
+							return err
 						}
 						if err := self.c.Git().Branch.Checkout(ref, cmdOptions); err != nil {
-							return self.c.Error(err)
+							return err
 						}
 
 						onSuccess()
@@ -80,16 +80,14 @@ func (self *RefsHelper) CheckoutRef(ref string, options types.CheckoutRefOptions
 							if err := self.c.Refresh(refreshOptions); err != nil {
 								return err
 							}
-							return self.c.Error(err)
+							return err
 						}
 						return self.c.Refresh(refreshOptions)
 					},
 				})
 			}
 
-			if err := self.c.Error(err); err != nil {
-				return err
-			}
+			return err
 		}
 		onSuccess()
 
@@ -142,7 +140,7 @@ func (self *RefsHelper) CheckoutRemoteBranch(fullBranchName string, localBranchN
 					// "git checkout -b", but we want to benefit from all the
 					// nice features of the CheckoutRef function.
 					if err := self.c.Git().Branch.CreateWithUpstream(localBranchName, fullBranchName); err != nil {
-						return self.c.Error(err)
+						return err
 					}
 					// Do a sync refresh to make sure the new branch is visible,
 					// so that we see an inline status when checking it out
@@ -176,7 +174,7 @@ func (self *RefsHelper) GetCheckedOutRef() *models.Branch {
 
 func (self *RefsHelper) ResetToRef(ref string, strength string, envVars []string) error {
 	if err := self.c.Git().Commit.ResetToCommit(ref, strength, envVars); err != nil {
-		return self.c.Error(err)
+		return err
 	}
 
 	self.c.Contexts().LocalCommits.SetSelection(0)
