@@ -71,9 +71,25 @@ func (self *ListController) scrollHorizontal(scrollFunc func()) error {
 }
 
 func (self *ListController) handleLineChange(change int) error {
-	before := self.context.GetList().GetSelectedLineIdx()
-	self.context.GetList().MoveSelectedLine(change)
-	after := self.context.GetList().GetSelectedLineIdx()
+	return self.handleLineChangeAux(
+		self.context.GetList().MoveSelectedLine, change,
+	)
+}
+
+func (self *ListController) HandleRangeSelectChange(change int) error {
+	return self.handleLineChangeAux(
+		self.context.GetList().ExpandNonStickyRange, change,
+	)
+}
+
+func (self *ListController) handleLineChangeAux(f func(int), change int) error {
+	list := self.context.GetList()
+
+	rangeBefore := list.IsSelectingRange()
+	before := list.GetSelectedLineIdx()
+	f(change)
+	rangeAfter := list.IsSelectingRange()
+	after := list.GetSelectedLineIdx()
 
 	if err := self.pushContextIfNotFocused(); err != nil {
 		return err
@@ -81,7 +97,18 @@ func (self *ListController) handleLineChange(change int) error {
 
 	// doing this check so that if we're holding the up key at the start of the list
 	// we're not constantly re-rendering the main view.
-	if before != after {
+	cursorMoved := before != after
+	if cursorMoved {
+		if change == -1 {
+			checkScrollUp(self.context.GetViewTrait(), self.c.UserConfig,
+				self.context.ModelIndexToViewIndex(before), self.context.ModelIndexToViewIndex(after))
+		} else if change == 1 {
+			checkScrollDown(self.context.GetViewTrait(), self.c.UserConfig,
+				self.context.ModelIndexToViewIndex(before), self.context.ModelIndexToViewIndex(after))
+		}
+	}
+
+	if cursorMoved || rangeBefore != rangeAfter {
 		return self.context.HandleFocus(types.OnFocusOpts{})
 	}
 
@@ -104,9 +131,25 @@ func (self *ListController) HandleGotoBottom() error {
 	return self.handleLineChange(self.context.GetList().Len())
 }
 
+func (self *ListController) HandleToggleRangeSelect() error {
+	list := self.context.GetList()
+
+	list.ToggleStickyRange()
+
+	return self.context.HandleFocus(types.OnFocusOpts{})
+}
+
+func (self *ListController) HandleRangeSelectDown() error {
+	return self.HandleRangeSelectChange(1)
+}
+
+func (self *ListController) HandleRangeSelectUp() error {
+	return self.HandleRangeSelectChange(-1)
+}
+
 func (self *ListController) HandleClick(opts gocui.ViewMouseBindingOpts) error {
 	prevSelectedLineIdx := self.context.GetList().GetSelectedLineIdx()
-	newSelectedLineIdx := opts.Y
+	newSelectedLineIdx := self.context.ViewIndexToModelIndex(opts.Y)
 	alreadyFocused := self.isFocused()
 
 	if err := self.pushContextIfNotFocused(); err != nil {
@@ -117,7 +160,7 @@ func (self *ListController) HandleClick(opts gocui.ViewMouseBindingOpts) error {
 		return nil
 	}
 
-	self.context.GetList().SetSelectedLineIdx(newSelectedLineIdx)
+	self.context.GetList().SetSelection(newSelectedLineIdx)
 
 	if prevSelectedLineIdx == newSelectedLineIdx && alreadyFocused && self.context.GetOnClick() != nil {
 		return self.context.GetOnClick()()
@@ -140,7 +183,7 @@ func (self *ListController) isFocused() bool {
 }
 
 func (self *ListController) GetKeybindings(opts types.KeybindingsOpts) []*types.Binding {
-	return []*types.Binding{
+	bindings := []*types.Binding{
 		{Tag: "navigation", Key: opts.GetKey(opts.Config.Universal.PrevItemAlt), Handler: self.HandlePrevLine},
 		{Tag: "navigation", Key: opts.GetKey(opts.Config.Universal.PrevItem), Handler: self.HandlePrevLine},
 		{Tag: "navigation", Key: opts.GetKey(opts.Config.Universal.NextItemAlt), Handler: self.HandleNextLine},
@@ -152,6 +195,18 @@ func (self *ListController) GetKeybindings(opts types.KeybindingsOpts) []*types.
 		{Tag: "navigation", Key: opts.GetKey(opts.Config.Universal.ScrollRight), Handler: self.HandleScrollRight},
 		{Tag: "navigation", Key: opts.GetKey(opts.Config.Universal.GotoBottom), Handler: self.HandleGotoBottom, Description: self.c.Tr.GotoBottom},
 	}
+
+	if self.context.RangeSelectEnabled() {
+		bindings = append(bindings,
+			[]*types.Binding{
+				{Tag: "navigation", Key: opts.GetKey(opts.Config.Universal.ToggleRangeSelect), Handler: self.HandleToggleRangeSelect, Description: self.c.Tr.ToggleRangeSelect},
+				{Tag: "navigation", Key: opts.GetKey(opts.Config.Universal.RangeSelectDown), Handler: self.HandleRangeSelectDown, Description: self.c.Tr.RangeSelectDown},
+				{Tag: "navigation", Key: opts.GetKey(opts.Config.Universal.RangeSelectUp), Handler: self.HandleRangeSelectUp, Description: self.c.Tr.RangeSelectUp},
+			}...,
+		)
+	}
+
+	return bindings
 }
 
 func (self *ListController) GetMouseKeybindings(opts types.KeybindingsOpts) []*gocui.ViewMouseBinding {
