@@ -75,66 +75,36 @@ func (self *StatusController) GetMouseKeybindings(opts types.KeybindingsOpts) []
 			Key:      gocui.MouseLeft,
 			Handler:  self.onClickMain,
 		},
+		{
+			ViewName: self.Context().GetViewName(),
+			Key:      gocui.MouseLeft,
+			Handler:  self.onClick,
+		},
 	}
 }
 
 func (self *StatusController) onClickMain(opts gocui.ViewMouseBindingOpts) error {
-	view := self.c.Views().Main
-
-	cx, cy := view.Cursor()
-	url, err := view.Word(cx, cy)
-	if err == nil && strings.HasPrefix(url, "https://") {
-		// Ignore errors (opening the link via the OS can fail if the
-		// `os.openLink` config key references a command that doesn't exist, or
-		// that errors when called.)
-		_ = self.c.OS().OpenLink(url)
-	}
-
-	return nil
+	return self.c.HandleGenericClick(self.c.Views().Main)
 }
 
 func (self *StatusController) GetOnRenderToMain() func() error {
-	versionStr := "master"
-	version, err := types.ParseVersionNumber(self.c.GetConfig().GetVersion())
-	if err == nil {
-		// Don't just take the version string as is, but format it again. This
-		// way it will be correct even if a distribution omits the "v", or the
-		// ".0" at the end.
-		versionStr = fmt.Sprintf("v%d.%d.%d", version.Major, version.Minor, version.Patch)
+	config := self.c.UserConfig.Gui
+
+	switch config.StatusPanelView {
+	case "dashboard":
+		return self.showDashboard
+	case "allBranchesLog":
+		return self.showAllBranchLogs
+	default:
+		return self.showDashboard
 	}
-
-	return func() error {
-		dashboardString := strings.Join(
-			[]string{
-				lazygitTitle(),
-				"Copyright 2022 Jesse Duffield",
-				fmt.Sprintf("Keybindings: %s", style.AttrUnderline.Sprint(fmt.Sprintf(constants.Links.Docs.Keybindings, versionStr))),
-				fmt.Sprintf("Config Options: %s", style.AttrUnderline.Sprint(fmt.Sprintf(constants.Links.Docs.Config, versionStr))),
-				fmt.Sprintf("Tutorial: %s", style.AttrUnderline.Sprint(constants.Links.Docs.Tutorial)),
-				fmt.Sprintf("Raise an Issue: %s", style.AttrUnderline.Sprint(constants.Links.Issues)),
-				fmt.Sprintf("Release Notes: %s", style.AttrUnderline.Sprint(constants.Links.Releases)),
-				style.FgMagenta.Sprintf("Become a sponsor: %s", style.AttrUnderline.Sprint(constants.Links.Donate)), // caffeine ain't free
-			}, "\n\n") + "\n"
-
-		return self.c.RenderToMainViews(types.RefreshMainOpts{
-			Pair: self.c.MainViewPairs().Normal,
-			Main: &types.ViewUpdateOpts{
-				Title: self.c.Tr.StatusTitle,
-				Task:  types.NewRenderStringTask(dashboardString),
-			},
-		})
-	}
-}
-
-func (self *StatusController) GetOnClick() func() error {
-	return self.onClick
 }
 
 func (self *StatusController) Context() types.Context {
 	return self.c.Contexts().Status
 }
 
-func (self *StatusController) onClick() error {
+func (self *StatusController) onClick(opts gocui.ViewMouseBindingOpts) error {
 	// TODO: move into some abstraction (status is currently not a listViewContext where a lot of this code lives)
 	currentBranch := self.c.Helpers().Refs.GetCheckedOutRef()
 	if currentBranch == nil {
@@ -146,21 +116,20 @@ func (self *StatusController) onClick() error {
 		return err
 	}
 
-	cx, _ := self.c.Views().Status.Cursor()
-	upstreamStatus := presentation.BranchStatus(currentBranch, types.ItemOperationNone, self.c.Tr, time.Now())
+	upstreamStatus := presentation.BranchStatus(currentBranch, types.ItemOperationNone, self.c.Tr, time.Now(), self.c.UserConfig)
 	repoName := self.c.Git().RepoPaths.RepoName()
 	workingTreeState := self.c.Git().Status.WorkingTreeState()
 	switch workingTreeState {
 	case enums.REBASE_MODE_REBASING, enums.REBASE_MODE_MERGING:
 		workingTreeStatus := fmt.Sprintf("(%s)", presentation.FormatWorkingTreeStateLower(self.c.Tr, workingTreeState))
-		if cursorInSubstring(cx, upstreamStatus+" ", workingTreeStatus) {
+		if cursorInSubstring(opts.X, upstreamStatus+" ", workingTreeStatus) {
 			return self.c.Helpers().MergeAndRebase.CreateRebaseOptionsMenu()
 		}
-		if cursorInSubstring(cx, upstreamStatus+" "+workingTreeStatus+" ", repoName) {
+		if cursorInSubstring(opts.X, upstreamStatus+" "+workingTreeStatus+" ", repoName) {
 			return self.c.Helpers().Repos.CreateRecentReposMenu()
 		}
 	default:
-		if cursorInSubstring(cx, upstreamStatus+" ", repoName) {
+		if cursorInSubstring(opts.X, upstreamStatus+" ", repoName) {
 			return self.c.Helpers().Repos.CreateRecentReposMenu()
 		}
 	}
@@ -235,6 +204,37 @@ func (self *StatusController) showAllBranchLogs() error {
 	})
 }
 
+func (self *StatusController) showDashboard() error {
+	versionStr := "master"
+	version, err := types.ParseVersionNumber(self.c.GetConfig().GetVersion())
+	if err == nil {
+		// Don't just take the version string as is, but format it again. This
+		// way it will be correct even if a distribution omits the "v", or the
+		// ".0" at the end.
+		versionStr = fmt.Sprintf("v%d.%d.%d", version.Major, version.Minor, version.Patch)
+	}
+
+	dashboardString := strings.Join(
+		[]string{
+			lazygitTitle(),
+			fmt.Sprintf("Copyright %d Jesse Duffield", time.Now().Year()),
+			fmt.Sprintf("Keybindings: %s", style.AttrUnderline.Sprint(fmt.Sprintf(constants.Links.Docs.Keybindings, versionStr))),
+			fmt.Sprintf("Config Options: %s", style.AttrUnderline.Sprint(fmt.Sprintf(constants.Links.Docs.Config, versionStr))),
+			fmt.Sprintf("Tutorial: %s", style.AttrUnderline.Sprint(constants.Links.Docs.Tutorial)),
+			fmt.Sprintf("Raise an Issue: %s", style.AttrUnderline.Sprint(constants.Links.Issues)),
+			fmt.Sprintf("Release Notes: %s", style.AttrUnderline.Sprint(constants.Links.Releases)),
+			style.FgMagenta.Sprintf("Become a sponsor: %s", style.AttrUnderline.Sprint(constants.Links.Donate)), // caffeine ain't free
+		}, "\n\n") + "\n"
+
+	return self.c.RenderToMainViews(types.RefreshMainOpts{
+		Pair: self.c.MainViewPairs().Normal,
+		Main: &types.ViewUpdateOpts{
+			Title: self.c.Tr.StatusTitle,
+			Task:  types.NewRenderStringTask(dashboardString),
+		},
+	})
+}
+
 func (self *StatusController) handleCheckForUpdate() error {
 	return self.c.Helpers().Update.CheckForUpdateInForeground()
 }
