@@ -50,7 +50,7 @@ func getBranchDisplayStrings(
 ) []string {
 	checkedOutByWorkTree := git_commands.CheckedOutByOtherWorktree(b, worktrees)
 	showCommitHash := fullDescription || userConfig.Gui.ShowBranchCommitHash
-	branchStatus := BranchStatus(b, itemOperation, tr, now)
+	branchStatus := BranchStatus(b, itemOperation, tr, now, userConfig)
 	worktreeIcon := lo.Ternary(icons.IsIconEnabled(), icons.LINKED_WORKTREE_ICON, fmt.Sprintf("(%s)", tr.LcWorktree))
 
 	// Recency is always three characters, plus one for the space
@@ -79,9 +79,9 @@ func getBranchDisplayStrings(
 	}
 
 	// Don't bother shortening branch names that are already 3 characters or less
-	if len(displayName) > utils.Max(availableWidth, 3) {
+	if len(displayName) > max(availableWidth, 3) {
 		// Never shorten the branch name to less then 3 characters
-		len := utils.Max(availableWidth, 4)
+		len := max(availableWidth, 4)
 		displayName = displayName[:len-1] + "…"
 	}
 	coloredName := nameTextStyle.Sprint(displayName)
@@ -106,7 +106,7 @@ func getBranchDisplayStrings(
 	}
 
 	if showCommitHash {
-		res = append(res, utils.ShortSha(b.CommitHash))
+		res = append(res, utils.ShortHash(b.CommitHash))
 	}
 
 	res = append(res, coloredName)
@@ -159,14 +159,25 @@ func branchStatusColor(branch *models.Branch, itemOperation types.ItemOperation)
 	return colour
 }
 
-func ColoredBranchStatus(branch *models.Branch, itemOperation types.ItemOperation, tr *i18n.TranslationSet) string {
-	return branchStatusColor(branch, itemOperation).Sprint(BranchStatus(branch, itemOperation, tr, time.Now()))
+func ColoredBranchStatus(
+	branch *models.Branch,
+	itemOperation types.ItemOperation,
+	tr *i18n.TranslationSet,
+	userConfig *config.UserConfig,
+) string {
+	return branchStatusColor(branch, itemOperation).Sprint(BranchStatus(branch, itemOperation, tr, time.Now(), userConfig))
 }
 
-func BranchStatus(branch *models.Branch, itemOperation types.ItemOperation, tr *i18n.TranslationSet, now time.Time) string {
+func BranchStatus(
+	branch *models.Branch,
+	itemOperation types.ItemOperation,
+	tr *i18n.TranslationSet,
+	now time.Time,
+	userConfig *config.UserConfig,
+) string {
 	itemOperationStr := ItemOperationToString(itemOperation, tr)
 	if itemOperationStr != "" {
-		return itemOperationStr + " " + utils.Loader(now)
+		return itemOperationStr + " " + utils.Loader(now, userConfig.Gui.Spinner)
 	}
 
 	if !branch.IsTrackingRemote() {
@@ -185,11 +196,11 @@ func BranchStatus(branch *models.Branch, itemOperation types.ItemOperation, tr *
 	}
 
 	result := ""
-	if branch.HasCommitsToPush() {
-		result = fmt.Sprintf("↑%s", branch.Pushables)
+	if branch.IsAheadForPull() {
+		result = fmt.Sprintf("↑%s", branch.AheadForPull)
 	}
-	if branch.HasCommitsToPull() {
-		result = fmt.Sprintf("%s↓%s", result, branch.Pullables)
+	if branch.IsBehindForPull() {
+		result = fmt.Sprintf("%s↓%s", result, branch.BehindForPull)
 	}
 
 	return result
