@@ -5,17 +5,26 @@ import (
 
 	"github.com/jesseduffield/lazygit/pkg/commands/models"
 	"github.com/jesseduffield/lazygit/pkg/commands/types/enums"
+	"github.com/jesseduffield/lazygit/pkg/config"
 	"github.com/jesseduffield/lazygit/pkg/gui/presentation/icons"
 	"github.com/jesseduffield/lazygit/pkg/gui/style"
 	"github.com/jesseduffield/lazygit/pkg/gui/types"
 	"github.com/jesseduffield/lazygit/pkg/i18n"
 )
 
-func FormatStatus(repoName string, currentBranch *models.Branch, itemOperation types.ItemOperation, linkedWorktreeName string, workingTreeState enums.RebaseMode, tr *i18n.TranslationSet) string {
+func FormatStatus(
+	repoName string,
+	currentBranch *models.Branch,
+	itemOperation types.ItemOperation,
+	linkedWorktreeName string,
+	workingTreeState enums.RebaseMode,
+	tr *i18n.TranslationSet,
+	userConfig *config.UserConfig,
+) string {
 	status := ""
 
 	if currentBranch.IsRealBranch() {
-		status += ColoredBranchStatus(currentBranch, itemOperation, tr) + " "
+		status += ColoredBranchStatus(currentBranch, itemOperation, tr, userConfig) + " "
 	}
 
 	if workingTreeState != enums.REBASE_MODE_NONE {
