@@ -367,8 +367,8 @@ func japaneseTranslationSet() TranslationSet {
 		OpenCommandLogMenu: "コマンドログメニューを開く",
 		// LcShowingGitDiff:                    "Showing output for:",
 		CommitDiff:                     "コミットの差分",
-		CopyCommitShaToClipboard:       "コミットのSHAをクリップボードにコピー",
-		CommitSha:                      "コミットのSHA",
+		CopyCommitHashToClipboard:      "コミットのhashをクリップボードにコピー",
+		CommitHash:                     "コミットのhash",
 		CommitURL:                      "コミットのURL",
 		CopyCommitMessageToClipboard:   "コミットメッセージをクリップボードにコピー",
 		CommitMessage:                  "コミットメッセージ",
@@ -496,7 +496,7 @@ func japaneseTranslationSet() TranslationSet {
 			CreateAnnotatedTag:                "注釈付きタグを作成",
 			CopyCommitMessageToClipboard:      "コミットメッセージをクリップボードにコピー",
 			CopyCommitDiffToClipboard:         "コミットの差分をクリップボードにコピー",
-			CopyCommitSHAToClipboard:          "コミットSHAをクリップボードにコピー",
+			CopyCommitHashToClipboard:         "コミットhashをクリップボードにコピー",
 			CopyCommitURLToClipboard:          "コミットのURLをクリップボードにコピー",
 			CopyCommitAuthorToClipboard:       "コミットの作成者名をクリップボードにコピー",
 			CopyCommitAttributeToClipboard:    "クリップボードにコピー",
