@@ -361,8 +361,8 @@ func koreanTranslationSet() TranslationSet {
 		OpenCommandLogMenu:                  "명령어 로그 메뉴 열기",
 		ShowingGitDiff:                      "Showing output for:",
 		CommitDiff:                          "커밋의 iff",
-		CopyCommitShaToClipboard:            "커밋 SHA를 클립보드에 복사",
-		CommitSha:                           "커밋 SHA",
+		CopyCommitHashToClipboard:           "커밋 해시를 클립보드에 복사",
+		CommitHash:                          "커밋 해시",
 		CommitURL:                           "커밋 URL",
 		CopyCommitMessageToClipboard:        "커밋 메시지를 클립보드에 복사",
 		CommitMessage:                       "커밋 메시지",
@@ -486,7 +486,7 @@ func koreanTranslationSet() TranslationSet {
 			CreateAnnotatedTag:                "Create annotated tag",
 			CopyCommitMessageToClipboard:      "커밋 메시지를 클립보드에 복사",
 			CopyCommitDiffToClipboard:         "커밋 diff를 클립보드에 복사",
-			CopyCommitSHAToClipboard:          "커밋 SHA를 클립보드에 복사",
+			CopyCommitHashToClipboard:         "커밋 해시를 클립보드에 복사",
 			CopyCommitURLToClipboard:          "커밋 URL를 클립보드에 복사",
 			CopyCommitAuthorToClipboard:       "커밋 작성자를 클립보드에 복사",
 			CopyCommitAttributeToClipboard:    "클립보드에 복사",
