@@ -548,8 +548,8 @@ func polishTranslationSet() TranslationSet {
 		OpenCommandLogMenuTooltip:             "Pokaż opcje dla dziennika poleceń, np. pokazywanie/ukrywanie dziennika poleceń i skupienie na dzienniku poleceń.",
 		ShowingGitDiff:                        "Pokazuje wynik dla:",
 		CommitDiff:                            "Różnice commita",
-		CopyCommitShaToClipboard:              "Kopiuj SHA commita do schowka",
-		CommitSha:                             "SHA commita",
+		CopyCommitHashToClipboard:             "Kopiuj hash commita do schowka",
+		CommitHash:                            "hash commita",
 		CommitURL:                             "URL commita",
 		CopyCommitMessageToClipboard:          "Kopiuj wiadomość commita do schowka",
 		CommitMessage:                         "Wiadomość commita",
@@ -784,7 +784,7 @@ func polishTranslationSet() TranslationSet {
 			CopyCommitMessageToClipboard:   "Kopiuj wiadomość commita do schowka",
 			CopyCommitSubjectToClipboard:   "Kopiuj temat commita do schowka",
 			CopyCommitDiffToClipboard:      "Kopiuj różnice commita do schowka",
-			CopyCommitSHAToClipboard:       "Kopiuj SHA commita do schowka",
+			CopyCommitHashToClipboard:      "Kopiuj hash commita do schowka",
 			CopyCommitURLToClipboard:       "Kopiuj URL commita do schowka",
 			CopyCommitAuthorToClipboard:    "Kopiuj autora commita do schowka",
 			CopyCommitAttributeToClipboard: "Kopiuj do schowka",
@@ -807,7 +807,6 @@ func polishTranslationSet() TranslationSet {
 			IgnoreExcludeFile:               "Ignoruj lub wyklucz plik",
 			IgnoreFileErr:                   "Nie można zignorować .gitignore",
 			ExcludeFile:                     "Wyklucz plik",
-			ExcludeFileErr:                  "Nie można wykluczyć .git/info/exclude",
 			ExcludeGitIgnoreErr:             "Nie można wykluczyć .gitignore",
 			Commit:                          "Commituj",
 			EditFile:                        "Edytuj plik",
@@ -888,11 +887,11 @@ func polishTranslationSet() TranslationSet {
 		},
 		Log: Log{
 			EditRebase:               "Rozpoczynanie interaktywnego rebazowania od '{{.ref}}'",
-			MoveCommitUp:             "Przenoszenie TODO w dół: '{{.shortSha}}'",
-			MoveCommitDown:           "Przenoszenie TODO w dół: '{{.shortSha}}'",
+			MoveCommitUp:             "Przenoszenie TODO w dół: '{{.shortHash}}'",
+			MoveCommitDown:           "Przenoszenie TODO w dół: '{{.shortHash}}'",
 			CherryPickCommits:        "Cherry-picking commitów:\n'{{.commitLines}}'",
 			HandleUndo:               "Cofanie ostatniego rozwiązania konfliktu",
-			HandleMidRebaseCommand:   "Aktualizacja akcji rebazowania commita {{.shortSha}} na '{{.action}}'",
+			HandleMidRebaseCommand:   "Aktualizacja akcji rebazowania commita {{.shortHash}} na '{{.action}}'",
 			RemoveFile:               "Usuwanie ścieżki '{{.path}}'",
 			CopyToClipboard:          "Kopiowanie '{{.str}}' do schowka",
 			Remove:                   "Usuwanie '{{.filename}}'",
