@@ -422,8 +422,8 @@ func RussianTranslationSet() TranslationSet {
 		OpenCommandLogMenu:                  "Открыть меню журнала команд",
 		ShowingGitDiff:                      "Показывает вывод для:",
 		CommitDiff:                          "Разница коммита",
-		CopyCommitShaToClipboard:            "Скопировать SHA коммита в буфер обмена",
-		CommitSha:                           "SHA коммита",
+		CopyCommitHashToClipboard:           "Скопировать hash коммита в буфер обмена",
+		CommitHash:                          "hash коммита",
 		CommitURL:                           "URL коммита",
 		CopyCommitMessageToClipboard:        "Скопировать сообщение коммита в буфер обмена",
 		CommitMessage:                       "Полное сообщение коммита",
@@ -579,7 +579,7 @@ func RussianTranslationSet() TranslationSet {
 			CopyCommitMessageToClipboard:      "Скопировать сообщение коммита в буфер обмена",
 			CopyCommitSubjectToClipboard:      "Скопировать тему коммита в буфер обмена",
 			CopyCommitDiffToClipboard:         "Скопировать сравнения коммита в буфер обмена",
-			CopyCommitSHAToClipboard:          "Скопировать SHA коммита в буфер обмена",
+			CopyCommitHashToClipboard:         "Скопировать hash коммита в буфер обмена",
 			CopyCommitURLToClipboard:          "Скопировать URL коммита в буфер обмена",
 			CopyCommitAuthorToClipboard:       "Скопировать автора коммита в буфер обмена",
 			CopyCommitAttributeToClipboard:    "Скопировать в буфер обмена",
@@ -599,7 +599,6 @@ func RussianTranslationSet() TranslationSet {
 			IgnoreExcludeFile:                 "Игнорировать или исключить файл",
 			IgnoreFileErr:                     "Невозможно игнорировать .gitignore",
 			ExcludeFile:                       "Исключить файл",
-			ExcludeFileErr:                    "Невозможно исключить .git/info/exclude",
 			ExcludeGitIgnoreErr:               "Невозможно исключить .gitignore",
 			Commit:                            "Коммит",
 			EditFile:                          "Редактировать файл",
