@@ -454,8 +454,8 @@ func traditionalChineseTranslationSet() TranslationSet {
 		OpenCommandLogMenu:                  "開啟命令記錄選單",
 		ShowingGitDiff:                      "顯示輸出：",
 		CommitDiff:                          "提交差異",
-		CopyCommitShaToClipboard:            "複製提交 SHA 到剪貼簿",
-		CommitSha:                           "提交 SHA",
+		CopyCommitHashToClipboard:           "複製提交 hash 到剪貼簿",
+		CommitHash:                          "提交 hash",
 		CommitURL:                           "提交 URL",
 		CopyCommitMessageToClipboard:        "複製提交訊息到剪貼簿",
 		CommitMessage:                       "提交訊息",
@@ -647,7 +647,7 @@ func traditionalChineseTranslationSet() TranslationSet {
 			CreateAnnotatedTag:                "建立附註標籤",
 			CopyCommitMessageToClipboard:      "將提交訊息複製到剪貼簿",
 			CopyCommitDiffToClipboard:         "將提交差異複製到剪貼簿",
-			CopyCommitSHAToClipboard:          "將提交 SHA 複製到剪貼簿",
+			CopyCommitHashToClipboard:         "將提交 hash 複製到剪貼簿",
 			CopyCommitURLToClipboard:          "將提交 URL 複製到剪貼簿",
 			CopyCommitAuthorToClipboard:       "將提交作者複製到剪貼簿",
 			CopyCommitAttributeToClipboard:    "複製到剪貼簿",
@@ -667,7 +667,6 @@ func traditionalChineseTranslationSet() TranslationSet {
 			IgnoreExcludeFile:                 "忽略或排除檔案",
 			IgnoreFileErr:                     "無法忽略 .gitignore 檔案",
 			ExcludeFile:                       "排除檔案",
-			ExcludeFileErr:                    "無法排除 .git/info/exclude 檔案",
 			ExcludeGitIgnoreErr:               "無法排除 .gitignore 檔案",
 			Commit:                            "提交",
 			EditFile:                          "編輯檔案",
