@@ -14,7 +14,9 @@ var Basic = NewIntegrationTest(NewIntegrationTestArgs{
 			NewBranch("mybranch").
 			CreateNCommits(10)
 	},
-	SetupConfig: func(cfg *config.AppConfig) {},
+	SetupConfig: func(cfg *config.AppConfig) {
+		cfg.AppState.GitLogShowGraph = "never"
+	},
 	Run: func(t *TestDriver, keys config.KeybindingConfig) {
 		markCommitAsBad := func() {
 			t.Views().Commits().
