@@ -11,7 +11,7 @@ var AmendOldCommit = NewIntegrationTest(NewIntegrationTestArgs{
 	Skip:         false,
 	IsDemo:       true,
 	SetupConfig: func(config *config.AppConfig) {
-		config.UserConfig.Gui.NerdFontsVersion = "3"
+		setDefaultDemoConfig(config)
 		config.UserConfig.Gui.ShowFileTree = false
 	},
 	SetupRepo: func(shell *Shell) {
