@@ -7,7 +7,7 @@ import (
 
 var RenameBranchAndPull = NewIntegrationTest(NewIntegrationTestArgs{
 	Description:  "Rename a branch to no longer match its upstream, then pull from the upstream",
-	ExtraCmdArgs: "",
+	ExtraCmdArgs: []string{},
 	Skip:         false,
 	SetupConfig:  func(config *config.AppConfig) {},
 	SetupRepo: func(shell *Shell) {
@@ -34,7 +34,7 @@ var RenameBranchAndPull = NewIntegrationTest(NewIntegrationTestArgs{
 			Press(keys.Branches.RenameBranch).
 			Tap(func() {
 				t.ExpectPopup().Confirmation().
-					Title(Equals("rename branch")).
+					Title(Equals("Rename branch")).
 					Content(Equals("This branch is tracking a remote. This action will only rename the local branch name, not the name of the remote branch. Continue?")).
 					Confirm()
 
